pub struct CommandDef {
pub id: String,
pub description: Option<String>,
pub schema: Option<CommandSchema>,
}Expand description
Description of a command as advertised across a channel.
Mirrors CommandDefinitionBaseSchema in the TypeScript protocol.
Fields
id: Stringdescription: Option<String>schema: Option<CommandSchema>Trait Implementations
Sourceimpl Clone for CommandDef
impl Clone for CommandDef
Sourcefn clone(&self) -> CommandDef
fn clone(&self) -> CommandDef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandDef
impl Debug for CommandDef
Sourceimpl<'de> Deserialize<'de> for CommandDef
impl<'de> Deserialize<'de> for CommandDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CommandDef
impl PartialEq for CommandDef
Sourcefn eq(&self, other: &CommandDef) -> bool
fn eq(&self, other: &CommandDef) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CommandDef
impl Serialize for CommandDef
impl StructuralPartialEq for CommandDef